A simple mlr3misc::Dictionary storing objects of class TuningSpace.
Each tuning space has an associated help page, see mlr_tuning_spaces_[id].
Arguments
Format
R6::R6Class object inheriting from mlr3misc::Dictionary.
Methods
See mlr3misc::Dictionary.
S3 methods
as.data.table(dict, ..., objects = FALSE)
mlr3misc::Dictionary -> data.table::data.table()
Returns a data.table::data.table() with fields "key", "label", "learner", and "n_values" as columns.
If objects is set to TRUE, the constructed objects are returned in the list column named object.